This directory is used to store the pretrained Remora models. To download all the pretrained models run ``remora model download``. 
You can also select a specific model based on pore type, modification, etc. For details run ``remora model download -h`` and ``remora model list_pretrained`` for a full list of available pretrained models.
